@@ -19,12 +19,12 @@
 """Top-level package for pylivemaker."""
 
 __author__ = """Peter Rowlands"""
-__email__ = 'peter@pmrowla.com'
-__license__ = 'GPLv3'
-__version__ = '0.2.2'
+__email__ = "peter@pmrowla.com"
+__license__ = "GPLv3"
+__version__ = "0.3.1"
 
 
 from .archive import LMArchive, LMArchiveInfo, LMCompressType
 from .lsb import LMScript, LNSCompiler, LNSDecompiler
 
-__all__ = ['LMArchive', 'LMArchiveInfo', 'LMCompressType', 'LMScript', 'LNSCompiler', 'LNSDecompiler']
+__all__ = ["LMArchive", "LMArchiveInfo", "LMCompressType", "LMScript", "LNSCompiler", "LNSDecompiler"]
