@@ -48,10 +48,10 @@ log = logging.getLogger(__name__)
 
 class LMCompressType(enum.IntEnum):
 
-    ZLIB = 0,               # zlib compressed
-    NONE = 1,               # uncompressed (used for already compressed media types)
-    ENCRYPTED = 2,          # LiveMaker Pro encrypted + uncompressed
-    ENCRYPTED_ZLIB = 3      # LiveMaker Pro encrypted + zlib compressed
+    ZLIB = (0,)  # zlib compressed
+    NONE = (1,)  # uncompressed (used for already compressed media types)
+    ENCRYPTED = (2,)  # LiveMaker Pro encrypted + uncompressed
+    ENCRYPTED_ZLIB = 3  # LiveMaker Pro encrypted + zlib compressed
 
 
 SUPPORTED_COMPRESSIONS = [
@@ -62,74 +62,266 @@ SUPPORTED_COMPRESSIONS = [
 ]
 
 # LM3 seed for TpRandom
-LIVEMAKER3_XOR_SEED = 0x75d6ee39
+LIVEMAKER3_XOR_SEED = 0x75D6EE39
 
 # VF archive key array for TVrFile.ChecksumStream
 VF_CHECKSUM_KEYS = [
-    0x00000000, 0x77073096, 0xee0e612c, 0x990951ba,
-    0x076dc419, 0x706af48f, 0xe963a535, 0x9e6495a3,
-    0x0edb8832, 0x79dcb8a4, 0xe0d5e91e, 0x97d2d988,
-    0x09b64c2b, 0x7eb17cbd, 0xe7b82d07, 0x90bf1d91,
-    0x1db71064, 0x6ab020f2, 0xf3b97148, 0x84be41de,
-    0x1adad47d, 0x6ddde4eb, 0xf4d4b551, 0x83d385c7,
-    0x136c9856, 0x646ba8c0, 0xfd62f97a, 0x8a65c9ec,
-    0x14015c4f, 0x63066cd9, 0xfa0f3d63, 0x8d080df5,
-    0x3b6e20c8, 0x4c69105e, 0xd56041e4, 0xa2677172,
-    0x3c03e4d1, 0x4b04d447, 0xd20d85fd, 0xa50ab56b,
-    0x35b5a8fa, 0x42b2986c, 0xdbbbc9d6, 0xacbcf940,
-    0x32d86ce3, 0x45df5c75, 0xdcd60dcf, 0xabd13d59,
-    0x26d930ac, 0x51de003a, 0xc8d75180, 0xbfd06116,
-    0x21b4f4b5, 0x56b3c423, 0xcfba9599, 0xb8bda50f,
-    0x2802b89e, 0x5f058808, 0xc60cd9b2, 0xb10be924,
-    0x2f6f7c87, 0x58684c11, 0xc1611dab, 0xb6662d3d,
-    0x76dc4190, 0x01db7106, 0x98d220bc, 0xefd5102a,
-    0x71b18589, 0x06b6b51f, 0x9fbfe4a5, 0xe8b8d433,
-    0x7807c9a2, 0x0f00f934, 0x9609a88e, 0xe10e9818,
-    0x7f6a0dbb, 0x086d3d2d, 0x91646c97, 0xe6635c01,
-    0x6b6b51f4, 0x1c6c6162, 0x856530d8, 0xf262004e,
-    0x6c0695ed, 0x1b01a57b, 0x8208f4c1, 0xf50fc457,
-    0x65b0d9c6, 0x12b7e950, 0x8bbeb8ea, 0xfcb9887c,
-    0x62dd1ddf, 0x15da2d49, 0x8cd37cf3, 0xfbd44c65,
-    0x4db26158, 0x3ab551ce, 0xa3bc0074, 0xd4bb30e2,
-    0x4adfa541, 0x3dd895d7, 0xa4d1c46d, 0xd3d6f4fb,
-    0x4369e96a, 0x346ed9fc, 0xad678846, 0xda60b8d0,
-    0x44042d73, 0x33031de5, 0xaa0a4c5f, 0xdd0d7cc9,
-    0x5005713c, 0x270241aa, 0xbe0b1010, 0xc90c2086,
-    0x5768b525, 0x206f85b3, 0xb966d409, 0xce61e49f,
-    0x5edef90e, 0x29d9c998, 0xb0d09822, 0xc7d7a8b4,
-    0x59b33d17, 0x2eb40d81, 0xb7bd5c3b, 0xc0ba6cad,
-    0xedb88320, 0x9abfb3b6, 0x03b6e20c, 0x74b1d29a,
-    0xead54739, 0x9dd277af, 0x04db2615, 0x73dc1683,
-    0xe3630b12, 0x94643b84, 0x0d6d6a3e, 0x7a6a5aa8,
-    0xe40ecf0b, 0x9309ff9d, 0x0a00ae27, 0x7d079eb1,
-    0xf00f9344, 0x8708a3d2, 0x1e01f268, 0x6906c2fe,
-    0xf762575d, 0x806567cb, 0x196c3671, 0x6e6b06e7,
-    0xfed41b76, 0x89d32be0, 0x10da7a5a, 0x67dd4acc,
-    0xf9b9df6f, 0x8ebeeff9, 0x17b7be43, 0x60b08ed5,
-    0xd6d6a3e8, 0xa1d1937e, 0x38d8c2c4, 0x4fdff252,
-    0xd1bb67f1, 0xa6bc5767, 0x3fb506dd, 0x48b2364b,
-    0xd80d2bda, 0xaf0a1b4c, 0x36034af6, 0x41047a60,
-    0xdf60efc3, 0xa867df55, 0x316e8eef, 0x4669be79,
-    0xcb61b38c, 0xbc66831a, 0x256fd2a0, 0x5268e236,
-    0xcc0c7795, 0xbb0b4703, 0x220216b9, 0x5505262f,
-    0xc5ba3bbe, 0xb2bd0b28, 0x2bb45a92, 0x5cb36a04,
-    0xc2d7ffa7, 0xb5d0cf31, 0x2cd99e8b, 0x5bdeae1d,
-    0x9b64c2b0, 0xec63f226, 0x756aa39c, 0x026d930a,
-    0x9c0906a9, 0xeb0e363f, 0x72076785, 0x05005713,
-    0x95bf4a82, 0xe2b87a14, 0x7bb12bae, 0x0cb61b38,
-    0x92d28e9b, 0xe5d5be0d, 0x7cdcefb7, 0x0bdbdf21,
-    0x86d3d2d4, 0xf1d4e242, 0x68ddb3f8, 0x1fda836e,
-    0x81be16cd, 0xf6b9265b, 0x6fb077e1, 0x18b74777,
-    0x88085ae6, 0xff0f6a70, 0x66063bca, 0x11010b5c,
-    0x8f659eff, 0xf862ae69, 0x616bffd3, 0x166ccf45,
-    0xa00ae278, 0xd70dd2ee, 0x4e048354, 0x3903b3c2,
-    0xa7672661, 0xd06016f7, 0x4969474d, 0x3e6e77db,
-    0xaed16a4a, 0xd9d65adc, 0x40df0b66, 0x37d83bf0,
-    0xa9bcae53, 0xdebb9ec5, 0x47b2cf7f, 0x30b5ffe9,
-    0xbdbdf21c, 0xcabac28a, 0x53b39330, 0x24b4a3a6,
-    0xbad03605, 0xcdd70693, 0x54de5729, 0x23d967bf,
-    0xb3667a2e, 0xc4614ab8, 0x5d681b02, 0x2a6f2b94,
-    0xb40bbe37, 0xc30c8ea1, 0x5a05df1b, 0x2d02ef8d,
+    0x00000000,
+    0x77073096,
+    0xEE0E612C,
+    0x990951BA,
+    0x076DC419,
+    0x706AF48F,
+    0xE963A535,
+    0x9E6495A3,
+    0x0EDB8832,
+    0x79DCB8A4,
+    0xE0D5E91E,
+    0x97D2D988,
+    0x09B64C2B,
+    0x7EB17CBD,
+    0xE7B82D07,
+    0x90BF1D91,
+    0x1DB71064,
+    0x6AB020F2,
+    0xF3B97148,
+    0x84BE41DE,
+    0x1ADAD47D,
+    0x6DDDE4EB,
+    0xF4D4B551,
+    0x83D385C7,
+    0x136C9856,
+    0x646BA8C0,
+    0xFD62F97A,
+    0x8A65C9EC,
+    0x14015C4F,
+    0x63066CD9,
+    0xFA0F3D63,
+    0x8D080DF5,
+    0x3B6E20C8,
+    0x4C69105E,
+    0xD56041E4,
+    0xA2677172,
+    0x3C03E4D1,
+    0x4B04D447,
+    0xD20D85FD,
+    0xA50AB56B,
+    0x35B5A8FA,
+    0x42B2986C,
+    0xDBBBC9D6,
+    0xACBCF940,
+    0x32D86CE3,
+    0x45DF5C75,
+    0xDCD60DCF,
+    0xABD13D59,
+    0x26D930AC,
+    0x51DE003A,
+    0xC8D75180,
+    0xBFD06116,
+    0x21B4F4B5,
+    0x56B3C423,
+    0xCFBA9599,
+    0xB8BDA50F,
+    0x2802B89E,
+    0x5F058808,
+    0xC60CD9B2,
+    0xB10BE924,
+    0x2F6F7C87,
+    0x58684C11,
+    0xC1611DAB,
+    0xB6662D3D,
+    0x76DC4190,
+    0x01DB7106,
+    0x98D220BC,
+    0xEFD5102A,
+    0x71B18589,
+    0x06B6B51F,
+    0x9FBFE4A5,
+    0xE8B8D433,
+    0x7807C9A2,
+    0x0F00F934,
+    0x9609A88E,
+    0xE10E9818,
+    0x7F6A0DBB,
+    0x086D3D2D,
+    0x91646C97,
+    0xE6635C01,
+    0x6B6B51F4,
+    0x1C6C6162,
+    0x856530D8,
+    0xF262004E,
+    0x6C0695ED,
+    0x1B01A57B,
+    0x8208F4C1,
+    0xF50FC457,
+    0x65B0D9C6,
+    0x12B7E950,
+    0x8BBEB8EA,
+    0xFCB9887C,
+    0x62DD1DDF,
+    0x15DA2D49,
+    0x8CD37CF3,
+    0xFBD44C65,
+    0x4DB26158,
+    0x3AB551CE,
+    0xA3BC0074,
+    0xD4BB30E2,
+    0x4ADFA541,
+    0x3DD895D7,
+    0xA4D1C46D,
+    0xD3D6F4FB,
+    0x4369E96A,
+    0x346ED9FC,
+    0xAD678846,
+    0xDA60B8D0,
+    0x44042D73,
+    0x33031DE5,
+    0xAA0A4C5F,
+    0xDD0D7CC9,
+    0x5005713C,
+    0x270241AA,
+    0xBE0B1010,
+    0xC90C2086,
+    0x5768B525,
+    0x206F85B3,
+    0xB966D409,
+    0xCE61E49F,
+    0x5EDEF90E,
+    0x29D9C998,
+    0xB0D09822,
+    0xC7D7A8B4,
+    0x59B33D17,
+    0x2EB40D81,
+    0xB7BD5C3B,
+    0xC0BA6CAD,
+    0xEDB88320,
+    0x9ABFB3B6,
+    0x03B6E20C,
+    0x74B1D29A,
+    0xEAD54739,
+    0x9DD277AF,
+    0x04DB2615,
+    0x73DC1683,
+    0xE3630B12,
+    0x94643B84,
+    0x0D6D6A3E,
+    0x7A6A5AA8,
+    0xE40ECF0B,
+    0x9309FF9D,
+    0x0A00AE27,
+    0x7D079EB1,
+    0xF00F9344,
+    0x8708A3D2,
+    0x1E01F268,
+    0x6906C2FE,
+    0xF762575D,
+    0x806567CB,
+    0x196C3671,
+    0x6E6B06E7,
+    0xFED41B76,
+    0x89D32BE0,
+    0x10DA7A5A,
+    0x67DD4ACC,
+    0xF9B9DF6F,
+    0x8EBEEFF9,
+    0x17B7BE43,
+    0x60B08ED5,
+    0xD6D6A3E8,
+    0xA1D1937E,
+    0x38D8C2C4,
+    0x4FDFF252,
+    0xD1BB67F1,
+    0xA6BC5767,
+    0x3FB506DD,
+    0x48B2364B,
+    0xD80D2BDA,
+    0xAF0A1B4C,
+    0x36034AF6,
+    0x41047A60,
+    0xDF60EFC3,
+    0xA867DF55,
+    0x316E8EEF,
+    0x4669BE79,
+    0xCB61B38C,
+    0xBC66831A,
+    0x256FD2A0,
+    0x5268E236,
+    0xCC0C7795,
+    0xBB0B4703,
+    0x220216B9,
+    0x5505262F,
+    0xC5BA3BBE,
+    0xB2BD0B28,
+    0x2BB45A92,
+    0x5CB36A04,
+    0xC2D7FFA7,
+    0xB5D0CF31,
+    0x2CD99E8B,
+    0x5BDEAE1D,
+    0x9B64C2B0,
+    0xEC63F226,
+    0x756AA39C,
+    0x026D930A,
+    0x9C0906A9,
+    0xEB0E363F,
+    0x72076785,
+    0x05005713,
+    0x95BF4A82,
+    0xE2B87A14,
+    0x7BB12BAE,
+    0x0CB61B38,
+    0x92D28E9B,
+    0xE5D5BE0D,
+    0x7CDCEFB7,
+    0x0BDBDF21,
+    0x86D3D2D4,
+    0xF1D4E242,
+    0x68DDB3F8,
+    0x1FDA836E,
+    0x81BE16CD,
+    0xF6B9265B,
+    0x6FB077E1,
+    0x18B74777,
+    0x88085AE6,
+    0xFF0F6A70,
+    0x66063BCA,
+    0x11010B5C,
+    0x8F659EFF,
+    0xF862AE69,
+    0x616BFFD3,
+    0x166CCF45,
+    0xA00AE278,
+    0xD70DD2EE,
+    0x4E048354,
+    0x3903B3C2,
+    0xA7672661,
+    0xD06016F7,
+    0x4969474D,
+    0x3E6E77DB,
+    0xAED16A4A,
+    0xD9D65ADC,
+    0x40DF0B66,
+    0x37D83BF0,
+    0xA9BCAE53,
+    0xDEBB9EC5,
+    0x47B2CF7F,
+    0x30B5FFE9,
+    0xBDBDF21C,
+    0xCABAC28A,
+    0x53B39330,
+    0x24B4A3A6,
+    0xBAD03605,
+    0xCDD70693,
+    0x54DE5729,
+    0x23D967BF,
+    0xB3667A2E,
+    0xC4614AB8,
+    0x5D681B02,
+    0x2A6F2B94,
+    0xB40BBE37,
+    0xC30C8EA1,
+    0x5A05DF1B,
+    0x2D02EF8D,
 ]
 
 MIN_ARCHIVE_VERSION = 100
@@ -159,15 +351,15 @@ class LMObfuscator(object):
         """
         key = 0
         while True:
-            key = ((key << 2) + key + seed) & 0xffffffff
+            key = ((key << 2) + key + seed) & 0xFFFFFFFF
             yield key
 
     def transform_bytes(self, data):
-        return construct.integers2bytes((b ^ (next(self.keystream) & 0xff)) for b in construct.iterateints(data))
+        return construct.integers2bytes((b ^ (next(self.keystream) & 0xFF)) for b in construct.iterateints(data))
 
     def transform_int(self, data):
         key = next(self.keystream)
-        data = [(b ^ ((key >> (8 * i)) & 0xff)) for i, b in enumerate(construct.iterateints(data))]
+        data = [(b ^ ((key >> (8 * i)) & 0xFF)) for i, b in enumerate(construct.iterateints(data))]
         return construct.integers2bytes(data)
 
     def transform_int_high(self, data):
@@ -175,9 +367,9 @@ class LMObfuscator(object):
         # LiveMaker always only outputs 0 or 0xffffffff depending on if high
         # bit ends up set
         key = next(self.keystream)
-        data = [(b ^ ((key >> (8 * i)) & 0xff)) for i, b in enumerate(construct.iterateints(data))]
+        data = [(b ^ ((key >> (8 * i)) & 0xFF)) for i, b in enumerate(construct.iterateints(data))]
         if data[3] & 0x80:
-            data = [0xff, 0xff, 0xff, 0xff]
+            data = [0xFF, 0xFF, 0xFF, 0xFF]
         else:
             data = [0, 0, 0, 0]
         return construct.integers2bytes(data)
@@ -191,7 +383,7 @@ class _LMArchiveVersionValidator(construct.Validator):
 
     def _decode(self, obj, ctx, path):
         if not self._validate(obj, ctx, path):
-            raise construct.ValidationError('Unsupported LiveMaker archive version: {}'.format(obj))
+            raise construct.ValidationError("Unsupported LiveMaker archive version: {}".format(obj))
         return obj
 
 
@@ -249,56 +441,50 @@ class LMArchiveDirectory(object):
             "signature" / construct.Const(b"vf"),
             "version" / _LMArchiveVersionValidator(construct.Int32ul),
             "count" / construct.Int32ul,
-            "filenames" / construct.Array(
+            "filenames"
+            / construct.Array(
                 construct.this.count,
                 construct.IfThenElse(
                     construct.this.version >= 100,
                     construct.Prefixed(
                         construct.Int32ul,
                         construct.Transformed(
-                            construct.GreedyString('cp932'),
+                            construct.GreedyString("cp932"),
                             LMObfuscator().transform_bytes,
                             None,
                             LMObfuscator().transform_bytes,
                             None,
                         ),
                     ),
-                    construct.PascalString(construct.Int32ul, 'cp932'),
-                )
+                    construct.PascalString(construct.Int32ul, "cp932"),
+                ),
             ),
-            "offsets" / construct.Array(
+            "offsets"
+            / construct.Array(
                 construct.this.count + 1,
                 construct.Struct(
-                    "offset_low" / construct.IfThenElse(
+                    "offset_low"
+                    / construct.IfThenElse(
                         construct.this._.version >= 100,
                         construct.Transformed(
-                            construct.Int32ul,
-                            LMObfuscator().transform_int,
-                            4,
-                            LMObfuscator().transform_int,
-                            4,
+                            construct.Int32ul, LMObfuscator().transform_int, 4, LMObfuscator().transform_int, 4,
                         ),
                         construct.Int32ul,
                     ),
                     # offset_high always 0 if ver < 101
-                    "offset_high" / construct.IfThenElse(
+                    "offset_high"
+                    / construct.IfThenElse(
                         construct.this._.version >= 101,
                         construct.Transformed(
-                            construct.Int32ul,
-                            LMObfuscator().transform_int,
-                            4,
-                            LMObfuscator().transform_int_high,
-                            4,
+                            construct.Int32ul, LMObfuscator().transform_int, 4, LMObfuscator().transform_int_high, 4,
                         ),
                         construct.Int32ul,
                     ),
                 ),
             ),
-            "compress_types" / construct.Array(
-                construct.this.count,
-                construct.Enum(construct.Byte, LMCompressType)
-            ),
-            "unk1s" / construct.Array(
+            "compress_types" / construct.Array(construct.this.count, construct.Enum(construct.Byte, LMCompressType)),
+            "unk1s"
+            / construct.Array(
                 construct.this.count,
                 # construct.Transformed(
                 #     construct.Int32ul,
@@ -309,14 +495,8 @@ class LMArchiveDirectory(object):
                 # ),
                 construct.Int32ul,
             ),
-            "checksums" / construct.Array(
-                construct.this.count,
-                construct.Int32ul,
-            ),
-            "encrypt_flags" / construct.Array(
-                construct.this.count,
-                construct.Byte,
-            ),
+            "checksums" / construct.Array(construct.this.count, construct.Int32ul,),
+            "encrypt_flags" / construct.Array(construct.this.count, construct.Byte,),
         )
 
     @classmethod
@@ -327,7 +507,7 @@ class LMArchiveDirectory(object):
     @classmethod
     def split_offset(cls, offset):
         """Split an offset into the expected components for writing to an archive."""
-        return {'offset_low': offset & 0xffffffff, 'offset_high': (offset >> 32) << 31}
+        return {"offset_low": offset & 0xFFFFFFFF, "offset_high": (offset >> 32) << 31}
 
     @classmethod
     def directory_size(cls, version, filenames=[]):
@@ -336,14 +516,14 @@ class LMArchiveDirectory(object):
         # a struct has a fixed size
         count = len(filenames)
         directory = {
-            'version': version,
-            'count': count,
-            'filenames': filenames,
-            'offsets': [cls.split_offset(0)] * (count + 1),
-            'compress_types': ['NONE'] * count,
-            'unk1s': [0] * count,
-            'checksums': [0] * count,
-            'encrypt_flags': [0] * count,
+            "version": version,
+            "count": count,
+            "filenames": filenames,
+            "offsets": [cls.split_offset(0)] * (count + 1),
+            "compress_types": ["NONE"] * count,
+            "unk1s": [0] * count,
+            "checksums": [0] * count,
+            "encrypt_flags": [0] * count,
         }
         return len(cls.struct().build(directory))
 
@@ -357,12 +537,12 @@ class LMArchiveDirectory(object):
             data (bytes): The data to checksum
 
         """
-        csum = 0xffffffff
+        csum = 0xFFFFFFFF
         for c in data:
-            x = (csum & 0xff) ^ c
+            x = (csum & 0xFF) ^ c
             x = VF_CHECKSUM_KEYS[x]
             csum = (csum >> 8) ^ x
-        return csum ^ 0xffffffff
+        return csum ^ 0xFFFFFFFF
 
 
 class LMArchive(object):
@@ -403,11 +583,11 @@ class LMArchive(object):
 
     """
 
-    def __init__(self, name=None, mode='r', fp=None, exe=None, split=False, version=DEFAULT_VERSION):
+    def __init__(self, name=None, mode="r", fp=None, exe=None, split=False, version=DEFAULT_VERSION):
         self.closed = True
         if not name and not fp:
-            raise ValueError('Nothing to open')
-        modes = {'r': 'rb', 'w': 'wb'}
+            raise ValueError("Nothing to open")
+        modes = {"r": "rb", "w": "wb"}
         if mode not in modes:
             raise ValueError("mode must be 'r' or 'w'")
         self.mode = mode
@@ -417,9 +597,9 @@ class LMArchive(object):
             fp = open(name, self._mode)
             self._extfp = False
         else:
-            if name is None and hasattr(fp, 'name') and isinstance(fp.name, (str, bytes)):
+            if name is None and hasattr(fp, "name") and isinstance(fp.name, (str, bytes)):
                 name = fp.name
-            if hasattr(fp, 'mode'):
+            if hasattr(fp, "mode"):
                 self._mode = fp.mode
             self._extfp = True
         self.fp = fp
@@ -432,10 +612,10 @@ class LMArchive(object):
         self.name_info = {}
 
         try:
-            if mode == 'w':
+            if mode == "w":
                 self._read_fps = []
                 if exe:
-                    self.exefp = open(exe, 'rb')
+                    self.exefp = open(exe, "rb")
                     self.is_exe = True
                     self.is_split = False
                     self.has_ext = False
@@ -445,9 +625,9 @@ class LMArchive(object):
                         self.is_split = True
                         self._split_base = root
                         self._split_files = set([self.name])
-                        if ext.lower() not in ['.dat', '.ext']:
-                            log.warn('Writing split archive index without .dat or .ext file extension.')
-                        elif ext.lower() == '.ext':
+                        if ext.lower() not in [".dat", ".ext"]:
+                            log.warn("Writing split archive index without .dat or .ext file extension.")
+                        elif ext.lower() == ".ext":
                             self.has_ext = True
                         else:
                             self.has_ext = False
@@ -465,23 +645,24 @@ class LMArchive(object):
                 savepos = self.fp.tell()
                 self.archive_offset = self._find_archive_offset()
                 self._parse_directory()
-                if ext.lower() in ['.dat', '.ext']:
+                if ext.lower() in [".dat", ".ext"]:
                     self.is_split = True
                     self._split_base = root
                     self._split_files = set([self.name])
-                    if ext.lower() == '.ext':
+                    if ext.lower() == ".ext":
                         self.has_ext = True
-                        dat_file = '{}.dat'.format(self._split_base)
+                        dat_file = "{}.dat".format(self._split_base)
                         if not os.path.isfile(dat_file):
                             raise BadLiveMakerArchive(
-                                'Could not find (.dat) data file for split archive index {}.'.format(self.name))
+                                "Could not find (.dat) data file for split archive index {}.".format(self.name)
+                            )
                         self._split_files.add(dat_file)
                         self._read_fps.append(open(dat_file, self._mode))
                     else:
                         self.has_ext = False
                         self._read_fps.append(self.fp)
                     for i in range(1, 100):
-                        dat_file = '{}.{:03}'.format(self._split_base, i)
+                        dat_file = "{}.{:03}".format(self._split_base, i)
                         if os.path.isfile(dat_file):
                             self._read_fps.append(open(dat_file, self._mode))
                             self._split_files.add(dat_file)
@@ -520,7 +701,7 @@ class LMArchive(object):
             return
 
         try:
-            if self.mode == 'w':
+            if self.mode == "w":
                 self._write_exe()
                 self._write_directory()
                 self._write_archive()
@@ -555,32 +736,40 @@ class LMArchive(object):
         """
         info = self.name_info.get(name)
         if info is None:
-            raise KeyError('{} does not exist in archive.'.format(name))
+            raise KeyError("{} does not exist in archive.".format(name))
         return info
 
     def list(self):
         """Print a list of archive entries to stdout."""
         print(self.name)
-        print('-------- ------ -------- -------- ------- ------')
-        print(' Length   Mode    unk1    Chksum   Flags   Name')
-        print('-------- ------ -------- -------- ------- ------')
+        print("-------- ------ -------- -------- ------- ------")
+        print(" Length   Mode    unk1    Chksum   Flags   Name")
+        print("-------- ------ -------- -------- ------- ------")
         for info in self.infolist():
-            print('{:8} {:6} {:08x} {:08x} {:02x} {}'.format(
-                info.compressed_size, info.compress_type.name, info.unk1, info.checksum, info.encrypt_flag, info.name))
+            print(
+                "{:8} {:6} {:08x} {:08x} {:02x} {}".format(
+                    info.compressed_size,
+                    info.compress_type.name,
+                    info.unk1,
+                    info.checksum,
+                    info.encrypt_flag,
+                    info.name,
+                )
+            )
 
     def _find_archive_offset(self):
         """Find offset for the start of the archive."""
         self.fp.seek(0)
-        if self.fp.read(2) == b'MZ':
+        if self.fp.read(2) == b"MZ":
             # File is an MS executable
             self.is_exe = True
             self.fp.seek(-2, 2)
             # Check for 'lv' trailer
-            if self.fp.read(2) != b'lv':
-                raise BadLiveMakerArchive('EXE does not contain a LiveMaker archive.')
+            if self.fp.read(2) != b"lv":
+                raise BadLiveMakerArchive("EXE does not contain a LiveMaker archive.")
             # Read offset for start of archive
             self.fp.seek(-6, 2)
-            offset, = struct.unpack('<I', self.fp.read(4))
+            (offset,) = struct.unpack("<I", self.fp.read(4))
             return offset
         else:
             self.is_exe = False
@@ -589,7 +778,10 @@ class LMArchive(object):
     def _parse_directory(self):
         """Parse the file index for this archive."""
         self.fp.seek(self.archive_offset)
-        directory = LMArchiveDirectory.struct().parse_stream(self.fp)
+        try:
+            directory = LMArchiveDirectory.struct().parse_stream(self.fp)
+        except construct.ConstructError as e:
+            raise BadLiveMakerArchive("Failed to parse VF directory: {}".format(e))
         self.version = directory.version
         filenames = directory.filenames
         offsets = directory.offsets
@@ -612,15 +804,15 @@ class LMArchive(object):
     def _extract(self, entry, output_path):
         """Extract the specified entry."""
         if self.closed:
-            raise ValueError('Archive is already closed.')
-        if self.mode != 'r':
-            raise ValueError('Cannot extract entry from archive which is open for writing.')
+            raise ValueError("Archive is already closed.")
+        if self.mode != "r":
+            raise ValueError("Cannot extract entry from archive which is open for writing.")
         if not isinstance(entry, LMArchiveInfo):
             entry = self.getinfo(entry)
         path = Path.joinpath(output_path, entry.path).expanduser().resolve()
         path.parent.mkdir(parents=True, exist_ok=True)
         data = self.read(entry)
-        with path.open('wb') as f:
+        with path.open("wb") as f:
             f.write(data)
 
     def extract(self, name, path=None):
@@ -669,7 +861,7 @@ class LMArchive(object):
             except UnsupportedLiveMakerCompression as e:
                 if not allow_unsupported:
                     raise e
-                log.warn('Skipping encrypted file {}'.format(e))
+                log.warn("Skipping encrypted file {}".format(e))
 
     def read(self, name, decompress=True, skip_checksum=True):
         """Return the bytes of the specified file in the archive.
@@ -690,21 +882,21 @@ class LMArchive(object):
 
         """
         if self.closed:
-            raise ValueError('Archive is already closed.')
-        if self.mode != 'r':
-            raise ValueError('Cannot read entry in archive which is open for writing.')
+            raise ValueError("Archive is already closed.")
+        if self.mode != "r":
+            raise ValueError("Cannot read entry in archive which is open for writing.")
         if isinstance(name, LMArchiveInfo):
             info = name
         else:
             info = self.getinfo(name)
         if decompress and info.compress_type not in SUPPORTED_COMPRESSIONS:
-            raise UnsupportedLiveMakerCompression('{} is unsupported'.format(info.compress_type))
+            raise UnsupportedLiveMakerCompression("{} is unsupported".format(info.compress_type))
         if self._read_fps:
             # archive data is split on 1GB (1024 * 1024 * 1024 bytes) boundaries
             # start reading from whichever data file contains the start of
             # this node, and then continue reading across boundary as needed
             offset = self.archive_offset + info._offset
-            data = b''
+            data = b""
             while len(data) < info.compressed_size:
                 bytes_needed = info.compressed_size - len(data)
                 fp = self._read_fps[offset // SPLIT_ARCHIVE_PART_SIZE]
@@ -718,7 +910,7 @@ class LMArchive(object):
             data = self.fp.read(info.compressed_size)
         if not skip_checksum and info.checksum is not None:
             if info.checksum != LMArchiveDirectory.checksum(data):
-                log.warn('Bad checksum for file {}.'.format(info.name))
+                log.warn("Bad checksum for file {}.".format(info.name))
         if decompress:
             if info.compress_type in (LMCompressType.ENCRYPTED, LMCompressType.ENCRYPTED_ZLIB):
                 data = decrypt(data)
@@ -739,11 +931,11 @@ class LMArchive(object):
 
         """
         if self.closed:
-            raise ValueError('Archive is already closed.')
-        if self.mode != 'r':
-            raise ValueError('Cannot read exe from archive which is open for writing.')
+            raise ValueError("Archive is already closed.")
+        if self.mode != "r":
+            raise ValueError("Cannot read exe from archive which is open for writing.")
         if not self.is_exe:
-            raise ValueError('Archive is not part of a LiveMaker excecutable.')
+            raise ValueError("Archive is not part of a LiveMaker excecutable.")
         self.fp.seek(0)
         return self.fp.read(self.archive_offset)
 
@@ -769,9 +961,9 @@ class LMArchive(object):
 
         """
         if self.closed:
-            raise ValueError('Archive is already closed.')
-        if self.mode != 'w':
-            raise ValueError('Cannot write to archive opened for reading.')
+            raise ValueError("Archive is already closed.")
+        if self.mode != "w":
+            raise ValueError("Cannot write to archive opened for reading.")
         if arcname is None:
             arcpath = PureWindowsPath(filename)
         else:
@@ -779,11 +971,11 @@ class LMArchive(object):
         # strip drive and leading pathsep
         name = str(arcpath.relative_to(arcpath.anchor))
         if name in self.name_info:
-            raise FileExistsError('{} already exists in this archive.'.format(name))
+            raise FileExistsError("{} already exists in this archive.".format(name))
         if compress_type is not None and compress_type not in SUPPORTED_COMPRESSIONS:
-            raise UnsupportedLiveMakerCompression('{} is not supported.'.format(compress_type))
+            raise UnsupportedLiveMakerCompression("{} is not supported.".format(compress_type))
         info = LMArchiveInfo(name)
-        with open(name, 'rb') as f:
+        with open(filename, "rb") as f:
             data = f.read()
         if compress_type is None:
             if len(data) >= 0x500000:
@@ -833,9 +1025,9 @@ class LMArchive(object):
 
         """
         if self.closed:
-            raise ValueError('Archive is already closed.')
-        if self.mode != 'w':
-            raise ValueError('Cannot write to archive opened for reading.')
+            raise ValueError("Archive is already closed.")
+        if self.mode != "w":
+            raise ValueError("Cannot write to archive opened for reading.")
         if isinstance(arcname, LMArchiveInfo):
             info = LMArchiveInfo(arcname.name)
             info.compress_type = arcname.compress_type
@@ -845,11 +1037,11 @@ class LMArchive(object):
             info.encrypt_flag = arcname.encrypt_flag
         else:
             if compress_type is None:
-                raise ValueError('Compression type must be specified')
+                raise ValueError("Compression type must be specified")
             info = LMArchiveInfo(arcname)
             info.compress_type = compress_type
         if info.name in self.name_info:
-            raise FileExistsError('{} already exists in this archive.'.format(arcname))
+            raise FileExistsError("{} already exists in this archive.".format(arcname))
         info.compressed_size = len(data)
         if info.checksum is None:
             info.checksum = LMArchiveDirectory.checksum(data)
@@ -865,23 +1057,23 @@ class LMArchive(object):
 
     def _write_directory(self):
         directory = {
-            'version': self.version,
-            'count': len(self.filelist),
-            'filenames': [],
-            'offsets': [],
-            'compress_types': [],
-            'unk1s': [],
-            'checksums': [],
-            'encrypt_flags': [],
+            "version": self.version,
+            "count": len(self.filelist),
+            "filenames": [],
+            "offsets": [],
+            "compress_types": [],
+            "unk1s": [],
+            "checksums": [],
+            "encrypt_flags": [],
         }
         self.archive_offset = archive_offset = self.fp.tell()
         directory_size = LMArchiveDirectory.directory_size(self.version, self.name_info.keys())
-        filenames = directory['filenames']
-        offsets = directory['offsets']
-        compress_types = directory['compress_types']
-        unk1s = directory['unk1s']
-        checksums = directory['checksums']
-        encrypt_flags = directory['encrypt_flags']
+        filenames = directory["filenames"]
+        offsets = directory["offsets"]
+        compress_types = directory["compress_types"]
+        unk1s = directory["unk1s"]
+        checksums = directory["checksums"]
+        encrypt_flags = directory["encrypt_flags"]
         for info in self.filelist:
             filenames.append(info.name)
             # info offset will be the offset of this entry in the temporary
@@ -913,7 +1105,7 @@ class LMArchive(object):
             self.tmpfp.seek(0, 2)
             data_offset = self.fp.tell()
             if data_offset > SPLIT_ARCHIVE_PART_SIZE:
-                raise BadLiveMakerArchive('Cannot generate split archive with exe+directory size > 1GB')
+                raise BadLiveMakerArchive("Cannot generate split archive with exe+directory size > 1GB")
             if self.has_ext:
                 total_size = self.tmpfp.tell()
                 extra_files = total_size // SPLIT_ARCHIVE_PART_SIZE
@@ -924,14 +1116,14 @@ class LMArchive(object):
                 extra_files -= 1
             self.tmpfp.seek(0)
             if self.has_ext:
-                dat_file = '{}.dat'.format(self._split_base)
+                dat_file = "{}.dat".format(self._split_base)
                 with open(dat_file, self._mode) as fp:
                     fp.write(self.tmpfp.read(SPLIT_ARCHIVE_PART_SIZE))
                 self._split_files.add(dat_file)
             else:
                 self.fp.write(self.tmpfp.read(SPLIT_ARCHIVE_PART_SIZE - data_offset))
             for i in range(1, extra_files + 1):
-                dat_file = '{}.{:03}'.format(self._split_base, i)
+                dat_file = "{}.{:03}".format(self._split_base, i)
                 with open(dat_file, self._mode) as fp:
                     fp.write(self.tmpfp.read(SPLIT_ARCHIVE_PART_SIZE))
                 self._split_files.add(dat_file)
@@ -941,9 +1133,9 @@ class LMArchive(object):
 
     def _write_trailer(self):
         if not self.is_split:
-            data = struct.pack('<I', self.archive_offset)
+            data = struct.pack("<I", self.archive_offset)
             self.fp.write(data)
-            self.fp.write(b'lv')
+            self.fp.write(b"lv")
 
 
 class LMArchiveInfo(object):
@@ -959,7 +1151,7 @@ class LMArchiveInfo(object):
 
     """
 
-    def __init__(self, name=''):
+    def __init__(self, name=""):
         self.name = name
         self._offset = 0
         self.compress_type = LMCompressType.NONE
