@@ -25,4 +25,4 @@ from .lmgraph import lmgraph
 from .lmlsb import lmlsb
 from .lmpatch import lmpatch
 
-__all__ = ['galconvert', 'lmar', 'lmgraph', 'lmlsb', 'lmpatch']
+__all__ = ["galconvert", "lmar", "lmgraph", "lmlsb", "lmpatch"]
